@@ -2,7 +2,6 @@
 from flask import Flask, request
 import json
 import ai_hub.globalvar as gl
-import ai_hub.log
 
 app = Flask("tccapi")
 
@@ -11,23 +10,22 @@ app = Flask("tccapi")
 def tccapi():
     ret = ""
     if request.method== 'POST':
-        data = request.get_data()
-        print("data: ", data)
+        #data = request.get_data()
+        #print("data: ", data)
 
         # inferserver
         #myinserver = gl.get_value("myinserver")
         inferserver = gl.get_value("inferserver")
         #print(inferserver)
 
-        data_pred = inferserver.pre_process(data)
-        print("pred_data: ",data_pred)
+        data_pred = inferserver.pre_process(request)
         ret = inferserver.pridect(data_pred)
         ret = inferserver.post_process(ret)
         if not isinstance(ret, str):
             ret = str(ret)
-        log.i("return: ", ret)
+        print("return: ", ret)
     else:
-        log.e("please use post request.such as ：curl localhost:8080/tccapi -X POST -d \'{\"img\"/:2}\'")
+        print("please use post request.such as ：curl localhost:8080/tccapi -X POST -d \'{\"img\"/:2}\'")
     return ret
 
 
@@ -40,7 +38,8 @@ class inferServer():
         gl.set_value("inferserver", self)
 
 
-    def pre_process(self, data):
+    def pre_process(self, request):
+        data = request.get_data()
         return data
 
     def post_process(self, data):
